@@ -25,6 +25,13 @@ pub enum Error {
     #[diagnostic(code(cxx2flow::from_utf8), help("error with UTF-8 decoding"))]
     FromUTF8(#[from] std::string::FromUtf8Error),
 
+    #[error("transparent")]
+    #[diagnostic(
+        code(cxx2flow::hashchain_insert_failed),
+        help("hashchain insert failed")
+    )]
+    InsertFailed(#[from] hash_chain::Error),
+
     #[error("target function not found")]
     #[diagnostic(
         code(cxx2flow::target_function_not_found),
@@ -43,18 +50,16 @@ pub enum Error {
         help("maybe source code is incomplete, \nplease check your input")
     )]
     DeclaratorNotFound,
-    
+
     #[error("child not found")]
     #[diagnostic(
         code(cxx2flow::child_not_found),
         help("maybe source code is incomplete, \nplease check your input")
     )]
     ChildNotFound,
-    
+
     #[error("treesitter parse failed")]
-    #[diagnostic(
-        code(cxx2flow::treesitter_parse_failed),
-    )]
+    #[diagnostic(code(cxx2flow::treesitter_parse_failed))]
     TreesitterParseFailed,
 
     #[diagnostic(
